@@ -1,4 +1,8 @@
 // Hack because debug builds force python36_d.lib
+// First undo the damage we're going to cause by undefining a reserved macro name
+#if defined(_MSC_VER) && defined(_DEBUG) && _MSC_VER >= 1930
+#include <corecrt.h>
+#endif
 #ifdef _DEBUG
 #undef _DEBUG
 #include <Python.h>
@@ -47,4 +51,4 @@ int main(int argc, char **argv)
     auto const ret{RUN_ALL_TESTS()};
 
     return ret;
-}
\ No newline at end of file
+}
